@@ -42,11 +42,11 @@ class layout(commands.Command):
 	@classmethod
 	def init_parser(cls, parser):
 		cls.modes = [
-			(cls.app.VIEW_MODE_HOR, _("horizontal"), _("show several views side by side")),
-			(cls.app.VIEW_MODE_VER, _("vertical"), _("show several views above each other")),
-			(cls.app.VIEW_MODE_ONE, _("one"), _("show only the currently focused view, as big as possible")),
-			(cls.app.PSEUDO_VIEW_MODE_SPLIT, _("split"), _("toggle between {hor} and {ver}").format(hor=cls.app.VIEW_MODE_HOR, ver=cls.app.VIEW_MODE_VER)),
-			(cls.app.PSEUDO_VIEW_MODE_AUTO, _("auto"), _("choose a layout depending on %layout.preferred%, %layout.required-width-for-hor% and %layout.required-height-for-ver%")),
+			(cls.app.VIEW_MODE_HOR, _("horizontal"), _("Show several views side by side")),
+			(cls.app.VIEW_MODE_VER, _("vertical"), _("Show several views above each other")),
+			(cls.app.VIEW_MODE_ONE, _("one"), _("Show only the currently focused view, as big as possible")),
+			(cls.app.PSEUDO_VIEW_MODE_SPLIT, _("split"), _("Toggle between {hor} and {ver}").format(hor=cls.app.VIEW_MODE_HOR, ver=cls.app.VIEW_MODE_VER)),
+			(cls.app.PSEUDO_VIEW_MODE_AUTO, _("auto"), _("Choose a layout depending on %layout.preferred%, %layout.required-width-for-hor% and %layout.required-height-for-ver%")),
 		]
 		parser.add_argument("mode", choices=[m[0] for m in cls.modes])
 
@@ -86,12 +86,12 @@ class go(commands.Command):
 	def init_parser(cls, parser):
 		modes = cls.app.go_map.keys()
 		parser.add_argument("direction", choices=modes)
-		parser.add_argument("--open-only", action="store_true", help="open but without focusing it if it is visible")
+		parser.add_argument("--open-only", action="store_true", help="Open but without focusing it if it is visible")
 		tag = parser.add_argument_group(_("tag options"))
 		exclusive = tag.add_mutually_exclusive_group()
-		exclusive.add_argument("--last", dest="containing", action="store_false", default=None, help=_("open the latest tag existing at the current commit"))
-		exclusive.add_argument("--containing", dest="containing", action="store_true", default=None, help=_("open the next tag containing the current commit"))
-		tag.add_argument("--toggle", action="store_true", default=None, help=_("return to the last view if the tag is already opened"))
+		exclusive.add_argument("--last", dest="containing", action="store_false", default=None, help=_("Open the latest tag existing at the current commit"))
+		exclusive.add_argument("--containing", dest="containing", action="store_true", default=None, help=_("Open the next tag containing the current commit"))
+		tag.add_argument("--toggle", action="store_true", default=None, help=_("Return to the last view if the tag is already opened"))
 
 	@classmethod
 	def init_help(cls, parser):
@@ -103,12 +103,12 @@ class go(commands.Command):
 		width = len(max(cls.app.go_map.keys(), key=len))
 		direction_fmt = '  {to:%s}  {help}' % width
 		direction_help = [
-			direction_fmt.format(to=cls.app.GO_DETAILS, help=_("open details")),
-			direction_fmt.format(to=cls.app.GO_TAG, help=_("open tag")),
-			direction_fmt.format(to=cls.app.GO_LOG, help=_("return to the first view")),
-			direction_fmt.format(to=cls.app.GO_LEFT, help=_("go to the previous view")),
-			direction_fmt.format(to=cls.app.GO_RIGHT, help=_("go to the next view")),
-			direction_fmt.format(to=cls.app.GO_TOGGLE, help=_("if several views are visible toggle between them")),
+			direction_fmt.format(to=cls.app.GO_DETAILS, help=_("Open details")),
+			direction_fmt.format(to=cls.app.GO_TAG, help=_("Open tag")),
+			direction_fmt.format(to=cls.app.GO_LOG, help=_("Return to the first view")),
+			direction_fmt.format(to=cls.app.GO_LEFT, help=_("Go to the previous view")),
+			direction_fmt.format(to=cls.app.GO_RIGHT, help=_("Go to the next view")),
+			direction_fmt.format(to=cls.app.GO_TOGGLE, help=_("If several views are visible toggle between them")),
 		]
 		parser.description += "\n".join(direction_help)
 
@@ -132,12 +132,12 @@ class help(commands.Command):
 	@classmethod
 	def init_parser(cls, parser):
 		group = parser.add_mutually_exclusive_group()
-		group.add_argument("--introduction", action="store_true", help=_("show a general help for this program"))
-		group.add_argument("--shortcuts", action="store_true", help=_("show a list of all defined keyboard shortcuts"))
-		group.add_argument("--commands", action="store_true", help=_("show a list of all available commands"))
-		group.add_argument("--settings", action="store_true", help=_("show a list of all available settings"))
+		group.add_argument("--introduction", action="store_true", help=_("Show a general help for this program"))
+		group.add_argument("--shortcuts", action="store_true", help=_("Show a list of all defined keyboard shortcuts"))
+		group.add_argument("--commands", action="store_true", help=_("Show a list of all available commands"))
+		group.add_argument("--settings", action="store_true", help=_("Show a list of all available settings"))
 
-		group.add_argument("-c", "--cmd", help=_("show the help for the specified command"))
+		group.add_argument("-c", "--cmd", help=_("Show the help for the specified command"))
 
 	def execute(self, args):
 		if args.commands:
@@ -163,12 +163,12 @@ class linenumber(commands.Command):
 	def init_parser(cls, parser):
 		cls.model = model.DetailsModel
 		group = parser.add_mutually_exclusive_group()
-		group.add_argument("--new", action='store_const', const=cls.model.linenumber_new, dest='_fmt', help=_("show the line numbers after the commit"))
-		group.add_argument("--old", action='store_const', const=cls.model.linenumber_old, dest='_fmt', help=_("show the line numbers before the commit (in case of a combined diff: left and right version)"))
-		group.add_argument("--old-left", action='store_const', const=cls.model.linenumber_old_left, dest='_fmt', help=_("show the line numbers before the commit (in case of a combined diff: the left version)"))
-		group.add_argument("--old-right", action='store_const', const=cls.model.linenumber_old_right, dest='_fmt', help=_("show the line numbers before the commit (in case of a combined diff: the right version)"))
-		group.add_argument("--toggle", action='store_true', help=_("toggle between --old and --new"))
-		group.add_argument("--off", action='store_const', const=cls.model.linenumber_off, dest='_fmt', help=_("do not show line numbers"))
+		group.add_argument("--new", action='store_const', const=cls.model.linenumber_new, dest='_fmt', help=_("Show the line numbers after the commit"))
+		group.add_argument("--old", action='store_const', const=cls.model.linenumber_old, dest='_fmt', help=_("Show the line numbers before the commit (in case of a combined diff: left and right version)"))
+		group.add_argument("--old-left", action='store_const', const=cls.model.linenumber_old_left, dest='_fmt', help=_("Show the line numbers before the commit (in case of a combined diff: the left version)"))
+		group.add_argument("--old-right", action='store_const', const=cls.model.linenumber_old_right, dest='_fmt', help=_("Show the line numbers before the commit (in case of a combined diff: the right version)"))
+		group.add_argument("--toggle", action='store_true', help=_("Toggle between --old and --new"))
+		group.add_argument("--off", action='store_const', const=cls.model.linenumber_off, dest='_fmt', help=_("Do not show line numbers"))
 
 	def execute(self, args):
 		if args.toggle:
@@ -211,9 +211,9 @@ class load(commands.Command):
 	@classmethod
 	def init_parser(cls, parser):
 		parser.add_argument('file', nargs='?')
-		parser.add_argument('--default-path', action='store_true', help=_("check the default paths even if git-viewer was started with --config, if file is given replace the filenames in the default paths with file"))
-		parser.add_argument('-l', '--log-level', choices=LOG_LEVEL_CHOICES, default=settings.LOG_LEVEL_NAME_WARNING, help=_('change %%app.log-level%% for loading this config file, defaults to %(default)s'))
-		parser.add_argument('-i', '--ignore-missing', action='store_true', help=_("don't print an error if file does not exist"))
+		parser.add_argument('--default-path', action='store_true', help=_("Check the default paths even if git-viewer was started with --config, if file is given replace the filenames in the default paths with file"))
+		parser.add_argument('-l', '--log-level', choices=LOG_LEVEL_CHOICES, default=settings.LOG_LEVEL_NAME_WARNING, help=_('Change %%app.log-level%% for loading this config file, defaults to %(default)s'))
+		parser.add_argument('-i', '--ignore-missing', action='store_true', help=_("Don't print an error if file does not exist"))
 
 	@classmethod
 	def init_help_lines(cls, parser):
@@ -252,12 +252,14 @@ class config_export(commands.Command):
 	@classmethod
 	def init_parser(cls, parser):
 		parser.add_argument('file', nargs='?')
-		parser.add_argument('--default-path', action='store_true', help=_("check the default paths even if git-viewer was started with --config, if file is given replace the filenames in the default paths with file"))
+		parser.add_argument('--default-path', action='store_true', help=_("Check the default paths even if git-viewer was started with --config, if file is given replace the filenames in the default paths with file"))
 
-		parser.add_argument('-f', '--force', action='store_true', help=_("overwrite existing file"))
+		parser.add_argument('-f', '--force', action='store_true', help=_("Overwrite existing file"))
 
-		parser.add_argument('--settings', action='store_true', default=None, help=_("export settings (`set`)"))
-		parser.add_argument('--keybindings', action='store_true', default=None, help=_("export keybindings (`map` and `map-fallback`)"))
+		parser.add_argument('--settings', action='store_true', default=None, help=_("Export settings (`set`)"))
+		parser.add_argument('--keybindings', action='store_true', default=None, help=_("Export keybindings (`map` and `map-fallback`)"))
+		parser.add_argument('--no-help', action='store_true', help=_("Do not add comments"))
+		parser.add_argument('--comment-out', action='store_true', help=_("Comment out all lines"))
 
 	@classmethod
 	def init_help_lines(cls, parser):
@@ -275,7 +277,7 @@ class config_export(commands.Command):
 		if args.settings is None and args.keybindings is None:
 			args.settings = True
 			args.keybindings = True
-		self.app.export_config(args.file, overwrite=args.force, settings=args.settings, keybindings=args.keybindings, default_path=args.default_path)
+		self.app.export_config(args.file, overwrite=args.force, settings=args.settings, keybindings=args.keybindings, default_path=args.default_path, comment_out=args.comment_out, export_help=not args.no_help)
 
 class config_edit(commands.Command):
 
@@ -295,8 +297,8 @@ class config_edit(commands.Command):
 	@classmethod
 	def init_parser(cls, parser):
 		parser.add_argument('file', nargs='?')
-		parser.add_argument('--default-path', action='store_true', help=_("check the default paths even if git-viewer was started with --config, if file is given replace the filenames in the default paths with file"))
-		parser.add_argument('-1', '--ignore-existing', action='store_true', help=_("open the first default path independent of whether it or other files are existing"))
+		parser.add_argument('--default-path', action='store_true', help=_("Check the default paths even if git-viewer was started with --config, if file is given replace the filenames in the default paths with file"))
+		parser.add_argument('-1', '--ignore-existing', action='store_true', help=_("Open the first default path independent of whether it or other files are existing"))
 
 	@classmethod
 	def init_help_lines(cls, parser):
@@ -333,11 +335,11 @@ class open(commands.Command):
 	@classmethod
 	def init_parser(cls, parser):
 		group = parser.add_mutually_exclusive_group()
-		group.add_argument("--after",  action='store_const', dest='version', const=cls.app.OPEN_AFTER,  help=_("open the version of the current file after this commit (read only)"))
-		group.add_argument("--before", action='store_const', dest='version', const=cls.app.OPEN_BEFORE_RIGHT, help=_("open the version of the current file before this commit (in case of a combined diff: the right version) (read only)"))
-		group.add_argument("--before-left", action='store_const', dest='version', const=cls.app.OPEN_BEFORE_LEFT, help=_("open the version of the current file before this commit (in case of a combined diff: the left version) (read only)"))
-		group.add_argument("--before-right", action='store_const', dest='version', const=cls.app.OPEN_BEFORE_RIGHT, help=_("open the version of the current file before this commit (in case of a combined diff: the right version) (read only)"))
-		group.add_argument("--now",    action='store_const', dest='version', const=cls.app.OPEN_NOW,    help=_("open the current file in the working directory (writable)"))
+		group.add_argument("--after",  action='store_const', dest='version', const=cls.app.OPEN_AFTER,  help=_("Open the version of the current file after this commit (read only)"))
+		group.add_argument("--before", action='store_const', dest='version', const=cls.app.OPEN_BEFORE_RIGHT, help=_("Open the version of the current file before this commit (in case of a combined diff: the right version) (read only)"))
+		group.add_argument("--before-left", action='store_const', dest='version', const=cls.app.OPEN_BEFORE_LEFT, help=_("Open the version of the current file before this commit (in case of a combined diff: the left version) (read only)"))
+		group.add_argument("--before-right", action='store_const', dest='version', const=cls.app.OPEN_BEFORE_RIGHT, help=_("Open the version of the current file before this commit (in case of a combined diff: the right version) (read only)"))
+		group.add_argument("--now",    action='store_const', dest='version', const=cls.app.OPEN_NOW,    help=_("Open the current file in the working directory (writable)"))
 		group.set_defaults(version=cls.app.OPEN_AFTER)
 
 	def execute(self, args):
@@ -444,10 +446,10 @@ class reload(commands.Command):
 
 	@classmethod
 	def init_parser(cls, parser):
-		parser.add_argument('--all', action='store_false', dest='only_current', help="""\
-		Reload the current view and all views left of it.
-		Discard all views right of the current view.
-		Automatically reopen if %%details-view.auto-open%% is enabled.""")
+		parser.add_argument('--all', action='store_false', dest='only_current', help=
+			"Reload the current view and all views left of it. "
+			"Discard all views right of the current view. "
+			"Automatically reopen if %%details-view.auto-open%% is enabled.")
 
 	def execute(self, args):
 		self.app.reload(args.only_current)
@@ -469,13 +471,13 @@ class search(commands.Command):
 	@classmethod
 	def init_parser(cls, parser):
 		group = parser.add_mutually_exclusive_group()
-		group.add_argument("--open", dest="cmd", action="store_const", const=cls.CMD_OPEN, default=cls.CMD_NEXT, help=_("open a text box to enter the search text"))
-		group.add_argument("--next", dest="cmd", action="store_const", const=cls.CMD_NEXT, help=_("go to the next match"))
-		group.add_argument("--prev", dest="cmd", action="store_const", const=cls.CMD_PREV, help=_("go to the previous match"))
-		group.add_argument("--edit", dest="cmd", action="store_const", const=cls.CMD_EDIT, help=_("open the text box to change the current search text"))
+		group.add_argument("--open", dest="cmd", action="store_const", const=cls.CMD_OPEN, default=cls.CMD_NEXT, help=_("Open a text box to enter the search text"))
+		group.add_argument("--next", dest="cmd", action="store_const", const=cls.CMD_NEXT, help=_("Go to the next match"))
+		group.add_argument("--prev", dest="cmd", action="store_const", const=cls.CMD_PREV, help=_("Go to the previous match"))
+		group.add_argument("--edit", dest="cmd", action="store_const", const=cls.CMD_EDIT, help=_("Open the text box to change the current search text"))
 
 		group = parser.add_argument_group(_("arguments for --open"))
-		group.add_argument("--reverse", action="store_true", help=_("search in reversed direction"))
+		group.add_argument("--reverse", action="store_true", help=_("Search in reversed direction"))
 
 		#TODO
 		#parser.add_argument("searchtext", nargs='?', help=("The text to search for."))
@@ -487,13 +489,13 @@ class search(commands.Command):
 
 		settings = {
 			'case_sensitive' : {
-				True : _("case sensitive"),
-				False : _("case insensitive"),
-				None : _("auto case sensitivity (case sensitive if search text contains upper case characters, case insensitive otherwise)"),
+				True : _("Case sensitive"),
+				False : _("Case insensitive"),
+				None : _("Auto case sensitivity (case sensitive if search text contains upper case characters, case insensitive otherwise)"),
 			},
 			'is_regex' : {
-				True : _("regular expression"),
-				False : _("literal string"),
+				True : _("Regular expression"),
+				False : _("Literal string"),
 			},
 		}
 
@@ -625,11 +627,11 @@ class set(commands.Command):
 	You can change several settings at once.
 	Each setting has one of the following formats:
 
-	    `key=value`  assign a value
-	    `key!`       toggle a boolean value or
+	    `key=value`  Assign a value
+	    `key!`       Toggle a boolean value or
 	                 cycle through a list of possible values
-	    `key`        set a boolean value to true
-	    `key?`       query a value
+	    `key`        Set a boolean value to true
+	    `key?`       Query a value
 
 	The allowed values for key and values are listed below in "available settings".
 
@@ -662,7 +664,7 @@ class set(commands.Command):
 	@classmethod
 	def init_parser(cls, parser):
 		parser.add_argument('setting', nargs='+')
-		parser.add_argument('-c', '--cycle', action='store_true', help=_("several values can be given for the same setting separated by commas, calling the command repeatedly will cycle through the given values"))
+		parser.add_argument('-c', '--cycle', action='store_true', help=_("Several values can be given for the same setting separated by commas, calling the command repeatedly will cycle through the given values"))
 
 	@classmethod
 	def init_help_lines(cls, parser):
@@ -672,10 +674,10 @@ class set(commands.Command):
 		out.append("")
 		out.append(_("data types:"))
 		data_types = (
-			(_("enum"), _("a set of allowed values")),
-			(_("int"), _("e.g. 42 or 0x23")),
-			(_("float"), _("e.g. 0.1")),
-			(_("str"), _("one or several arbitrary characters")),
+			(_("enum"), _("A set of allowed values")),
+			(_("int"), _("E.g. 42 or 0x23")),
+			(_("float"), _("E.g. 0.1")),
+			(_("str"), _("One or several arbitrary characters")),
 			(_("color"), _("foreground[,emphases][/background]")),
 			("",         _("The square brackets indicate that emphasis and background are optional.")),
 			("",         _("Several emphasis values can be given separated by commas.")),
@@ -688,16 +690,16 @@ class set(commands.Command):
 			("",         _("background colors:")),
 			("",         _("    default, black, red, green, yellow, blue, magenta, cyan, white")),
 			("",         _("Bright colors do not work with curses, see %app.display-module%.")),
-			(_("coloredstr"), _("a str which may contain markup for colors:")),
+			(_("coloredstr"), _("A str which may contain markup for colors:")),
 			("",              _("<color=value>...</color>")),
 			("",              _("where value is a color as explained for data type color")),
-			(_("cmd"), _("a shell command to generate the content to be displayed")),
+			(_("cmd"), _("A shell command to generate the content to be displayed")),
 			("",       _("(This is not actually executed in a shell, shell command as opposed to the internal commands which can be mapped to keys.)")),
 			("",       _("This is usually a git command but can be replaced by a custom script.")),
 			("",       _("Additionally a few specialized internal functions are available (see below).")),
 			("",       _("Several subprocesses can be given, separated by a semicolon. Their outputs are concatenated.")),
-			("",       _("The syntax is shell-like, parsed with shlex.shlex(value, posix=True, punctuation_chars=';').")),
-			(_("list"), _("a comma separated list of an arbitrary number of items")),
+			("",       _("The syntax is shell-like, parsed with shlex.shlex(value, posix=True, punctuation_chars=';') and whitespace_split=True.")),
+			(_("list"), _("A comma separated list of an arbitrary number of items")),
 		)
 		out.extend(cls.AlignedLine("  "+ln) for ln in utils.format_table(data_types, col_sep="  ^"))
 
@@ -719,7 +721,7 @@ class set(commands.Command):
 			if funcdesc:
 				out.append("      " + funcdesc)
 			if funcconf:
-				out.append("      related settings:")
+				out.append("      Related settings:")
 				pattern =  "          %{}%"
 				for key in funcconf:
 					out.append(pattern.format(key))
@@ -880,7 +882,7 @@ class set(commands.Command):
 				for v in value.split(","):
 					v = self.parse_single_value(key, attr, v, allowed_values)
 					out.append(v)
-				return out, True
+				return out
 
 			for thisvalname, thisvalue, thishelp in settings.iter_allowed_values(allowed_values):
 				if thisvalname == value:
@@ -890,6 +892,7 @@ class set(commands.Command):
 
 		if allowed_values == settings.TYPE_COMMAND:
 			s = shlex.shlex(value, posix=True, punctuation_chars=';')
+			s.whitespace_split = True
 			out = [[]]
 			for word in s:
 				if word == ';':
@@ -1093,7 +1096,7 @@ class unmap_fallback(commands.Command):
 
 	@classmethod
 	def init_parser(cls, parser):
-		parser.add_argument('primitive', help=_("the primitive command from which you want to remove the fallback command"))
+		parser.add_argument('primitive', help=_("The primitive command from which you want to remove the fallback command"))
 
 	def execute(self, args):
 		self.app.unbind_fallback(args.primitive)
@@ -1123,8 +1126,8 @@ class resize(commands.Command):
 
 	@classmethod
 	def init_parser(cls, parser):
-		parser.add_argument('--move-border', '-m', action='store_true', help=_("move the right border of the currently focused view or the left border if the currently focused view is the right most view (instead of increasing the size of the currently focused view and decreasing the size of all other views)"))
-		parser.add_argument('step', type=int, help=_("how much to increase the size of the current view in percent of the complete window size. Pass a negative number to decrease the size."))
+		parser.add_argument('--move-border', '-m', action='store_true', help=_("Move the right border of the currently focused view or the left border if the currently focused view is the right most view (instead of increasing the size of the currently focused view and decreasing the size of all other views)"))
+		parser.add_argument('step', type=int, help=_("How much to increase the size of the current view in percent of the complete window size. Pass a negative number to decrease the size."))
 
 	def execute(self, args):
 		if args.move_border:
@@ -1146,9 +1149,9 @@ class visual(commands.Command):
 	@classmethod
 	def init_parser(cls, parser):
 		group = parser.add_mutually_exclusive_group()
-		group.add_argument("--on",  action='store_const', dest='arg', const=cls.app.VISUAL_ON,  help=_("lines can be selected"))
-		group.add_argument("--off", action='store_const', dest='arg', const=cls.app.VISUAL_OFF, help=_("lines cannot be selected"))
-		group.add_argument("--toggle", action='store_const', dest='arg', const=cls.app.VISUAL_TOGGLE, help=_("toggle between --on and --off"))
+		group.add_argument("--on",  action='store_const', dest='arg', const=cls.app.VISUAL_ON,  help=_("Lines can be selected"))
+		group.add_argument("--off", action='store_const', dest='arg', const=cls.app.VISUAL_OFF, help=_("Lines cannot be selected"))
+		group.add_argument("--toggle", action='store_const', dest='arg', const=cls.app.VISUAL_TOGGLE, help=_("Toggle between --on and --off"))
 		group.set_defaults(arg=cls.app.VISUAL_ON)
 
 	def execute(self, args):
@@ -1223,9 +1226,9 @@ class yank(commands.Command):
 		parser.add_argument("format", nargs='*', default='hash')
 		parser.add_argument("--primary",   "-p", dest="selection", action="store_const", const=cls.SELECTION_PRIMARY, default=cls.SELECTION_CLIPBOARD)
 		parser.add_argument("--clipboard", "-c", dest="selection", action="store_const", const=cls.SELECTION_CLIPBOARD)
-		parser.add_argument("--no-git", "-n", action="store_true", help=_("do not replace git placeholders (works also with unstaged and uncommitted changes)"))
-		parser.add_argument("--follow", "-f", action="store_true", help=_("select a hash id which you want to copy the information for (like with the command `link`)"))
-		parser.add_argument("--verbose", action="store_true", help=_("show the command used to copy the information"))
+		parser.add_argument("--no-git", "-n", action="store_true", help=_("Do not replace git placeholders (works also with unstaged and uncommitted changes)"))
+		parser.add_argument("--follow", "-f", action="store_true", help=_("Select a hash id which you want to copy the information for (like with the command `link`)"))
+		parser.add_argument("--verbose", action="store_true", help=_("Show the command used to copy the information"))
 
 	@classmethod
 	def init_help(cls, parser):
@@ -1297,31 +1300,34 @@ class yank(commands.Command):
 	# ------- commands -------
 
 	def get_id(self, hash_id, type_id):
-		"""the internally used id; except for commits, where it copies the full hash instead of the short hash"""
+		"""The internally used id; except for commits, where it copies the full hash instead of the short hash"""
 		if type_id == self.app.TYPE_OTHER:
 			return "%H"
 		return hash_id
 
 	def get_cwd(self, hash_id, type_id):
-		"""current working directory"""
+		"""Current working directory"""
 		return os.getcwd()
 
 	def get_type(self, hash_id, type_id):
-		"""git object type"""
+		"""Git object type"""
 		if hash_id in (self.app.ID_STAGED, self.app.ID_UNSTAGED, self.app.ID_UNTRACKED, self.app.ID_STASHES_GROUP):
 			return hash_id
 		return model.get_object_type(hash_id)
 
 	def get_last_search_term(self, hash_id, type_id):
+		"""The last search term"""
 		search_edit = self.app.search_edit
 		if not search_edit:
 			raise ErrorInCommand(_("nothing has been searched for yet"))
 		return self.app.search_edit.get_last_input()
 
 	def get_rel_path(self, hash_id, type_id):
+		"""In details view: The path of the current file relative to the current working directory"""
 		return self.app.get_current_file_path()
 
 	def get_abs_path(self, hash_id, type_id):
+		"""In details view: The absolute path of the current file"""
 		fn = self.app.get_current_file_path()
 		if fn:
 			fn = os.path.abspath(fn)
@@ -1410,9 +1416,9 @@ class add_editor(commands.Command):
 
 	@classmethod
 	def init_parser(cls, parser):
-		parser.add_argument("name", help=_("the name which is used in the settings for this editor. This is usually the same like the command to be executed, i.e. the value of EDITOR, but if it's not you can set that later by changing the setting editor.<name>.command."))
-		parser.add_argument("-l", "--linenumber", default="", help=_("a command line argument to be added to the editor command to specify the line number, should include the wildcard {ln}"))
-		parser.add_argument("-r", "--readonly", default="", help=_("a command line argument to be added to the editor command to specify that the file is supposed to be opened read only"))
+		parser.add_argument("name", help=_("The name which is used in the settings for this editor. This is usually the same like the command to be executed, i.e. the value of EDITOR, but if it's not you can set that later by changing the setting editor.<name>.command."))
+		parser.add_argument("-l", "--linenumber", default="", help=_("A command line argument to be added to the editor command to specify the line number, should include the wildcard {ln}"))
+		parser.add_argument("-r", "--readonly", default="", help=_("A command line argument to be added to the editor command to specify that the file is supposed to be opened read only"))
 
 	def execute(self, args):
 		self.app.model.opener.add_editor(args.name, linenumber=args.linenumber, readonly=args.readonly)
@@ -1427,7 +1433,7 @@ class debug(commands.Command):
 	def init_parser(cls, parser):
 		group = parser.add_mutually_exclusive_group()
 		group.add_argument("--show-line-id", action='store_true')
-		group.add_argument("--show-screen-type", action='store_true', help=_("if %%app.display-module%% is auto you can use this to check which display module was loaded"))
+		group.add_argument("--show-screen-type", action='store_true', help=_("If %%app.display-module%% is auto you can use this to check which display module was loaded"))
 		group.add_argument("--show-main-views-index", action='store_true')
 
 	def execute(self, args):
